#
# Constants for Gtkinter
#

#ANCHORED = 32768
ARROW_DOWN = 1
ARROW_LEFT = 2
ARROW_RIGHT = 3
ARROW_UP = 0
BASIC = 65536
#BEING_DESTROYED = 2
BUTTONBOX_DEFAULT = -1
BUTTONBOX_DEFAULT_STYLE = 0
BUTTONBOX_EDGE = 2
BUTTONBOX_END = 4
BUTTONBOX_SPREAD = 1
BUTTONBOX_START = 3
CAN_DEFAULT = 8192
CAN_FOCUS = 2048
CELL_EMPTY = 0
CELL_PIXMAP = 2
CELL_PIXTEXT = 3
CELL_TEXT = 1
CELL_WIDGET = 4
CENTIMETERS = 2
CURVE_TYPE_FREE = 2
CURVE_TYPE_LINEAR = 0
CURVE_TYPE_SPLINE = 1
DESTROYED = 1
DIRECTION_LEFT = 0
DIRECTION_RIGHT = 1
DIR_DOWN = 3
DIR_LEFT = 4
DIR_RIGHT = 5
DIR_TAB_BACKWARD = 1
DIR_TAB_FORWARD = 0
DIR_UP = 2
EXPAND = 1
FALSE = 0
FLOATING = 2
FILL = 4
HAS_DEFAULT = 16384
HAS_FOCUS = 4096
HAS_GRAB = 32768
#HAS_SHAPE_MASK = 4194304
INCHES = 1
#IN_CALL = 4
JUSTIFY_CENTER = 2
JUSTIFY_FILL = 3
JUSTIFY_LEFT = 0
JUSTIFY_RIGHT = 1
LEFT_RIGHT = 1
MAPPED = 128
MENU_FACTORY_MENU = 0
MENU_FACTORY_MENU_BAR = 1
MENU_FACTORY_OPTION_MENU = 2
#NEED_DESTROY = 1
NO_WINDOW = 32
ORIENTATION_HORIZONTAL = 0
ORIENTATION_VERTICAL = 1
PACK_END = 1
PACK_START = 0
PARENT_SENSITIVE = 1024
PIXELS = 0
POLICY_ALWAYS = 0
POLICY_AUTOMATIC = 1
POS_BOTTOM = 3
POS_LEFT = 0
POS_RIGHT = 1
POS_TOP = 2
PREVIEW_COLOR = 0
PREVIEW_GRAYSCALE = 1
PRIORITY_HIGH = -20
PRIORITY_INTERNAL = -10
PRIORITY_DEFAULT = 0
PRIORITY_LOW = 10
#PROPAGATE_STATE = 16384
RC_STYLE = 262144
REALIZED = 64
#REDRAW_PENDING = 524288
RESERVED_1 = 4
RESERVED_2 = 8
RESERVED_3 = 131072
#RESIZE_NEEDED = 2097152
#RESIZE_PENDING = 1048576
RUN_BOTH = 3
RUN_FIRST = 1
RUN_LAST = 2
RUN_MASK = 15
RUN_NO_RECURSE = 16
SCROLL_NONE = 0
SCROLL_PAGE_BACKWARD = 3
SCROLL_PAGE_FORWARD = 4
SCROLL_STEP_BACKWARD = 1
SCROLL_STEP_FORWARD = 2
SELECTION_BROWSE = 1
SELECTION_EXTENDED = 3
SELECTION_MULTIPLE = 2
SELECTION_SINGLE = 0
SENSITIVE = 512
SHADOW_ETCHED_IN = 3
SHADOW_ETCHED_OUT = 4
SHADOW_IN = 1
SHADOW_NONE = 0
SHADOW_OUT = 2
SHRINK = 2
STATE_ACTIVE = 1
STATE_INSENSITIVE = 4
STATE_NORMAL = 0
STATE_PRELIGHT = 2
STATE_SELECTED = 3
TOOLBAR_BOTH = 2
TOOLBAR_ICONS = 0
TOOLBAR_TEXT = 1
TOP_BOTTOM = 0
TOPLEVEL = 16
TREE_VIEW_ITEM = 1
TREE_VIEW_LINE = 0
TROUGH_END = 2
TROUGH_NONE = 0
TROUGH_START = 1
TRUE = 1
TYPE_ARGS = 16
TYPE_BOOL = 3
TYPE_BOXED = 13
TYPE_CALLBACK = 15
TYPE_CHAR = 2
TYPE_C_CALLBACK = 19
TYPE_DOUBLE = 9
TYPE_ENUM = 11
TYPE_FLAGS = 12
TYPE_FLOAT = 8
TYPE_FOREIGN = 14
TYPE_INT = 4
TYPE_INVALID = 0
TYPE_LONG = 6
TYPE_NONE = 1
TYPE_NUM_BUILTINS = 57
TYPE_OBJECT = 20
TYPE_POINTER = 17
TYPE_SIGNAL = 18
TYPE_STRING = 10
TYPE_UINT = 5
TYPE_ULONG = 7
#UNMAPPED = 32
UPDATE_ALWAYS = 1
UPDATE_CONTINUOUS = 0
UPDATE_DELAYED = 2
UPDATE_DISCONTINUOUS = 1
UPDATE_IF_VALID = 2
UPDATE_SNAP_TO_TICKS = 4
#USER_STYLE = 131072
VISIBILITY_NONE = 0
VISIBILITY_PARTIAL = 1
VISIBILITY_FULL = 2
VISIBLE = 256
WINDOW_DIALOG = 1
WINDOW_POPUP = 2
WINDOW_TOPLEVEL = 0
WIN_POS_CENTER = 1
WIN_POS_MOUSE = 2
WIN_POS_NONE = 0

